#
# spec file for package cflow
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cflow
Version:        1.7
Release:        bp155.1.6
Summary:        Tool to generate flowcharts for C sources
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://www.gnu.org/software/cflow
Source0:        https://ftp.gnu.org/gnu/cflow/cflow-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/cflow/cflow-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  flex
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}

%description
GNU cflow analyzes a collection of C source files and prints a graph, charting
control flow within the program. GNU cflow is able to produce both direct and
inverted flowgraphs for C sources. Optionally a cross-reference listing can be
generated. Two output formats are implemented: POSIX and GNU (extended). Input
files can optionally be preprocessed before analyzing.

%prep
%setup -q

%build
%configure \
  --disable-silent-rules
%make_build

%check
%make_build check

%install
%make_install
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files -f %{name}.lang
%license COPYING
%doc NEWS README AUTHORS
%{_bindir}/%{name}
%{_infodir}/%{name}.info%{?ext_info}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.7:
  * Multiple start functions are allowed
  * New option --target=FUNCTION
  * New output format: dot
  The '-f dot' (or '--format=dot') option instructs cflow to output
  graph as a description in DOT language, suitable as input to graphviz
  programs.
  * Bugfixes:
  * * CVE-2019-16165
  * * CVE-2019-16166
  * * Fix parsing of K&R style function declarations
  * * Improve parsing of typecasts
  * * Fix recursive call detection
* Wed Jun 19 2019 Martin Pluskal <mpluskal@suse.com>
- Update license information
* Mon Feb 25 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file with spec-cleaner
* Sat Feb 23 2019 seanlew@opensuse.org
- Update to version 1.6:
  * New option --all (-A)
  * New option --no-main
* Wed May 18 2016 mpluskal@suse.com
- Update to version 1.5:
  * Correctly handle functions returning struct/union (fixes bug
    [#31792])
  * Gracefully handle invalid inputs (fixes bug #44113)
  * Debugging output goes to stderr
  * Add a manpage
  * Consistent use of exit codes
- Cleanup spec file with spec-cleaner
- Use url for source
- Add gpg signature
* Fri Oct 14 2011 puzel@suse.com
- update to cflow-1.4
  * Symbol aliases
    The `--symbol' option has been extended to allow for defining
    symbol aliases.  Aliases are useful for declaring reserved
    words such as `__restrict' or `__inline'.  For example,
    the option `--symbol __restrict:=restrict' instructs cflow
    to treat `__restrict' exactly as `restrict'.
  * New syntactic class: qualifiers
    Tokens in this class can legitimately appear in place of C
    qualifiers, such as `static' or `inline'.  This class is useful
    for some compiler-depending keywords, such as `__extension__'
    in gcc.  The usual declaration of this symbol is `--symbol
    __extension__:qualifier'.
  * Speed up recursive call detection.
  * Fix parsing of typedefs after `struct'.
  * Fix the output of branch marks in tree mode.
  * Fix processing of static inline functions (RH bug 650716).
- drop cflow-fix-yyparse-return-type.patch (upstream)
* Mon Apr 11 2011 puzel@novell.com
- use spec-cleaner
* Sun Jul 12 2009 puzel@novell.com
- update to cflow-1.3
  * Optimize symbol tables.
  * New symbol tables considerably improve the program performance.
  * Bugfixes.
- drop cflow-fix-extern-inline.patch (fixed upstream)
* Mon Jan  5 2009 puzel@suse.cz
- do 'make check' in spec
* Wed Dec 17 2008 puzel@suse.cz
- initial package (version 1.2)
